@@ -17,11 +17,10 @@
 """Module containing the Abstract classes for the Network."""
 import abc
 
-import pandas as pd
 import numpy as np
+import pandas as pd
 from cached_property import cached_property
 
-
 from bluepysnap import utils
 from bluepysnap.exceptions import BluepySnapError
 
@@ -29,51 +28,39 @@ from bluepysnap.exceptions import BluepySnapError
 class NetworkObject(abc.ABC):
     """Abstract class for the top level NetworkObjects accessor."""
 
+    _population_class = None
+
     def __init__(self, circuit):
         """Initialize the top level NetworkObjects accessor."""
         self._circuit = circuit
 
-    def _get_populations(self, cls, config):
+    def _get_populations(self, cls):
         """Collects the different NetworkObjectPopulation and returns them as a dict."""
-        res = {}
-        for file_config in config:
-            storage = cls(file_config, self._circuit)
-            for population in storage.population_names:  # pylint: disable=not-an-iterable
-                if population in res:
-                    raise BluepySnapError(
-                        f"Duplicated {self.__class__.__name__} population: '{population}'")
-                res[population] = storage.population(population)
-        return res
-
-    @abc.abstractmethod
-    def _collect_populations(self):
-        """Should specify the self._get_populations arguments."""
-
-    @cached_property
-    def _config(self):
-        return self._circuit.config
+        return {name: cls(self._circuit, name) for name in self.population_names}
 
     @cached_property
     def _populations(self):
         """Cached population dictionary."""
-        return self._collect_populations()
+        return self._get_populations(self._population_class)
 
     @cached_property
+    @abc.abstractmethod
     def population_names(self):
-        """Returns all the sorted NetworkObjects population names from the Circuit."""
-        return sorted(self._populations)
+        """Should define all sorted NetworkObjects population names from the Circuit."""
 
     @cached_property
     def property_dtypes(self):
         """Returns all the NetworkObjects property dtypes for the Circuit."""
+
         def _update(d, index, value):
             if d.setdefault(index, value) != value:
-                raise BluepySnapError("Same property with different "
-                                      f"dtype. {index}: {value}!= {d[index]}")
+                raise BluepySnapError(
+                    f"Same property with different dtype. {index}: {value}!= {d[index]}"
+                )
 
         res = {}
         for pop in self.values():
-            for varname, dtype in pop.property_dtypes.iteritems():
+            for varname, dtype in pop.property_dtypes.items():
                 _update(res, varname, dtype)
         return pd.Series(res)
 
@@ -159,7 +146,7 @@ class NetworkObject(abc.ABC):
 
     @abc.abstractmethod
     def get(self, group=None, properties=None):
-        """Returns the properties of a the NetworkObject."""
+        """Returns the properties of the NetworkObject."""
         ids = self.ids(group)
         properties = utils.ensure_list(properties)
         # We don t convert to set properties itself to keep the column order.
@@ -169,14 +156,25 @@ class NetworkObject(abc.ABC):
         if unknown_props:
             raise BluepySnapError(f"Unknown properties required: {unknown_props}")
 
-        res = pd.DataFrame(index=ids.index, columns=properties)
-        for name, pop in self.items():
+        # Retrieve the dtypes of the selected properties.
+        # However, the int dtype may not be preserved if some values are NaN.
+        dtypes = {
+            column: dtype
+            for column, dtype in self.property_dtypes.items()
+            if column in properties_set
+        }
+        dataframes = [pd.DataFrame(columns=properties, index=ids.index_schema).astype(dtypes)]
+        for name, pop in sorted(self.items()):
+            # since ids is sorted, global_pop_ids should be sorted as well
             global_pop_ids = ids.filter_population(name)
             pop_ids = global_pop_ids.get_ids()
-            pop_properties = properties_set & pop.property_names
-            # indices from Population and get functions are different so I cannot
-            # use a dataframe equal directly and properties have different types so cannot use a
-            # multi dim numpy array
-            for prop in pop_properties:
-                res.loc[global_pop_ids.index, prop] = pop.get(pop_ids, prop).to_numpy()
-        return res.sort_index()
+            if len(pop_ids) > 0:
+                pop_properties = properties_set & pop.property_names
+                # Since the columns are passed as Series, index cannot be specified directly.
+                # However, it's a bit more performant than converting the Series to numpy arrays.
+                pop_df = pd.DataFrame({prop: pop.get(pop_ids, prop) for prop in pop_properties})
+                pop_df.index = global_pop_ids.index
+                dataframes.append(pop_df)
+        res = pd.concat(dataframes)
+        assert res.index.is_monotonic_increasing, "The index should be already sorted"
+        return res
