@@ -16,45 +16,32 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 """Simulation access."""
 
+from pathlib import Path
+
 from cached_property import cached_property
 
-from bluepysnap.node_sets import NodeSets
-from bluepysnap.config import Config
+from bluepysnap.config import SimulationConfig
 from bluepysnap.exceptions import BluepySnapError
-
-
-def _resolve_config(config):
-    """Resolve the config file if global ('network' and 'simulation' keys).
-
-    Args:
-        config (str/dict): the path to the configuration file or a dict containing the config.
-
-    Returns:
-        dict: the complete simulation config file.
-    """
-    content = Config(config).resolve()
-    if "simulation" in content and "network" in content:
-        simulation_path = content["simulation"]
-        res = Config(str(simulation_path)).resolve()
-        if "network" not in res:
-            res["network"] = str(content["network"])
-        return res
-    return content
+from bluepysnap.node_sets import NodeSets
 
 
 def _collect_frame_reports(sim):
     """Collect the different frame reports."""
     res = {}
-    for name, report in sim.config["reports"].items():
-        report_type = report.get("sections", "soma")
+    for name in sim.to_libsonata.list_report_names:
+        report = sim.to_libsonata.report(name)
+        report_type = report.sections.name
         if report_type == "soma":
             from bluepysnap.frame_report import SomaReport
+
             cls = SomaReport
         elif report_type == "all":
             from bluepysnap.frame_report import CompartmentReport
+
             cls = CompartmentReport
         else:
             raise BluepySnapError(f"Report {name}: format {report_type} not yet supported.")
+
         res[name] = cls(sim, name)
     return res
 
@@ -71,40 +58,51 @@ class Simulation:
         Returns:
             Simulation: A Simulation object.
         """
-        self._config = _resolve_config(config)
+        self._config = SimulationConfig.from_config(config)
+
+    @property
+    def to_libsonata(self):
+        """Libsonata instance of the config."""
+        return self._config.to_libsonata
 
     @property
     def config(self):
         """Simulation config dictionary."""
-        return self._config
+        return self._config.to_dict()
 
     @cached_property
     def circuit(self):
         """Access to the circuit used for the simulation."""
         from bluepysnap.circuit import Circuit
-        if "network" not in self._config:
-            raise BluepySnapError("No 'network' set in the simulation/global config file.")
-        return Circuit(self._config["network"])
+
+        if not Path(self.to_libsonata.network).is_file():
+            raise BluepySnapError(f"'network' file not found: {self.to_libsonata.network}")
+        return Circuit(self.to_libsonata.network)
+
+    @property
+    def output(self):
+        """Access the output section."""
+        return self.to_libsonata.output
 
     @property
     def run(self):
         """Access to the complete run dictionary for this simulation."""
-        return self._config["run"]
+        return self.to_libsonata.run
 
     @property
     def time_start(self):
         """Returns the starting time of the simulation."""
-        return self.run.get("tstart", 0)
+        return 0
 
     @property
     def time_stop(self):
         """Returns the stopping time of the simulation."""
-        return self.run["tstop"]
+        return self.run.tstop
 
     @property
     def dt(self):
         """Returns the frequency of reporting in milliseconds."""
-        return self.run.get("dt", None)
+        return self.run.dt
 
     @property
     def time_units(self):
@@ -115,24 +113,25 @@ class Simulation:
     @property
     def conditions(self):
         """Access to the conditions dictionary for this simulation."""
-        return self._config.get("conditions", {})
+        return getattr(self.to_libsonata, "conditions", None)
 
     @property
     def simulator(self):
         """Returns the targeted simulator."""
-        return self._config["target_simulator"]
+        target_simulator = getattr(self.to_libsonata, "target_simulator", None)
+        return target_simulator.name if target_simulator is not None else None
 
     @cached_property
     def node_sets(self):
         """Returns the NodeSets object bound to the simulation."""
-        if "node_sets_file" in self._config:
-            return NodeSets(self._config["node_sets_file"])
-        return {}
+        node_sets_file = self.to_libsonata.node_sets_file
+        return NodeSets(node_sets_file) if node_sets_file else {}
 
     @cached_property
     def spikes(self):
         """Access to the SpikeReport."""
         from bluepysnap.spike_report import SpikeReport
+
         return SpikeReport(self)
 
     @cached_property
